/*
 * Instantlauncher. Author: Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 * This project is released under Creative Commons Zero (CC0) license.
 */
package eu.svjatoslav.instantlauncher;

import eu.svjatoslav.instantlauncher.configuration.ConfigurationManager;
import eu.svjatoslav.instantlauncher.configuration.FileAssociation;

import java.io.File;
import java.io.IOException;

import static eu.svjatoslav.instantlauncher.Utils.runOpeningApplication;

public class InstantLauncher {

    private final MainFrame mainFrame;
    public ConfigurationManager configurationManager;

    public InstantLauncher() throws IOException {
        configurationManager = new ConfigurationManager();
        mainFrame = new MainFrame(this);
    }

    public static void exitProgram() {
        System.exit(0);
    }

    /**
     * @return <code>true</code> if file was opened. <code>false</code> if
     * unknown file type.
     */
    public boolean openFile(final File file) {
        FileAssociation fileAssociation = configurationManager.getConfiguration().findFileAssociation(file);
        if (fileAssociation == null) return false;

        runOpeningApplication(fileAssociation.command, file);
        return true;
    }

    public void run() {
        mainFrame.show();
    }

    public void openDirectory(File chosenFile) {
        runOpeningApplication(configurationManager.getConfiguration().directoryOpenCommand, chosenFile);
    }

    public void openDirectoryInTerminal(File chosenFile) {
        runOpeningApplication(configurationManager.getConfiguration().directoryTerminalOpenCommand, chosenFile);
    }

}
