/*
 * Instantlauncher. Author: Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 * This project is released under Creative Commons Zero (CC0) license.
 */
package eu.svjatoslav.instantlauncher;

import eu.svjatoslav.instantlauncher.menu.MultiLevelMenu;

import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

class MainFrame {

    private final InstantLauncher instantLauncher;
    private JFrame frame;
    private boolean isShowing;

    public MainFrame(final InstantLauncher instantLauncher) {
        this.instantLauncher = instantLauncher;
    }

    private void buildContentPane() {

        final MultiLevelMenu multiLevelMenu = new MultiLevelMenu(instantLauncher);
        frame.getContentPane().add(multiLevelMenu.buildContentPanel(), BorderLayout.CENTER);

    }

    public void show() {

        if (!isShowing) {
            // initialize frame
            frame = new JFrame("InstantLauncher");

            buildContentPane();

            // registor window listener
            final FrameWindowListener windowListener = new FrameWindowListener();
            frame.addWindowListener(windowListener);

            // maximize window
            frame.setExtendedState(JFrame.MAXIMIZED_BOTH);
            frame.setVisible(true);

            isShowing = true;
        }

    }

    private static class FrameWindowListener implements WindowListener {

        @Override
        public void windowActivated(final WindowEvent e) {
        }

        @Override
        public void windowClosed(final WindowEvent e) {
        }

        @Override
        public void windowClosing(final WindowEvent e) {
            InstantLauncher.exitProgram();
        }

        @Override
        public void windowDeactivated(final WindowEvent e) {
        }

        @Override
        public void windowDeiconified(final WindowEvent e) {
        }

        @Override
        public void windowIconified(final WindowEvent e) {
        }

        @Override
        public void windowOpened(final WindowEvent e) {
        }

    }

}
